<?php

namespace App\Http\Controllers;

use Aws\Textract\TextractClient;
use Google\Cloud\Vision\V1\ImageAnnotatorClient;
use GuzzleHttp\Client;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;
use thiagoalessio\TesseractOCR\TesseractOCR;

class ImageController extends Controller
{
    public function test(){
        return 'Test';
    }

    public function uploadImage(Request $request)
    {

        // Validate the uploaded image
        $request->validate([
            'image' => 'required|image|mimes:jpeg,png,jpg|max:2048',
        ]);

        // Store the uploaded image in the 'public' storage
        $imagePath = $request->file('image')->store('uploads', 'public');
        $imageFile = storage_path('app/public/' . $imagePath);

        // Create an Amazon Textract client
        $textractClient = new TextractClient([
            'version' => 'latest',
            'region'  => env('AWS_DEFAULT_REGION'),
            'credentials' => [
                'key' => env('AWS_ACCESS_KEY_ID'),
                'secret' => env('AWS_SECRET_ACCESS_KEY'),
            ]
        ]);

        // Read the image contents
        $imageData = file_get_contents($imageFile);

        // Send the image to Textract for text extraction
        $result = $textractClient->detectDocumentText([
            'Document' => [
                'Bytes' => $imageData,
            ],
        ]);

        // Process the extracted text
        $rawText = '';
        foreach ($result['Blocks'] as $block) {
            if ($block['BlockType'] == 'LINE') {
                $rawText .= $block['Text'] . "\n";
            }
        }
        $structuredData = $this->generateStructure($rawText);
        // Return the structured data as a JSON response
        return response()->json([
            'structured_data' =>$structuredData
        ]);
    }

    public function generateStructure($rawText)
    {
        $response = Http::withHeaders([
            'Authorization' => 'Bearer ' . env('OPENAI_API_KEY'),
        ])->post('https://api.openai.com/v1/chat/completions', [
            'model' => 'gpt-3.5-turbo',
            'messages' => [
                [
                    'role' => 'system',
                    'content' => 'You are a helpful assistant that formats raw text into structured JSON. Only return the JSON object without any additional formatting or comments.'
                ],
                [
                    'role' => 'user',
                    'content' => $this->buildPrompt($rawText)
                ],
            ],
            'max_tokens' => 1000,
            'temperature' => 0.7,
        ]);
        Log::info($response);
        // Extract the content from the API response
        $responseContent = $response->json('choices.0.message.content');

        // Remove any unwanted formatting such as markdown
        $cleanedContent = trim($responseContent, "```json \n");

        // Decode the cleaned JSON content
        return json_decode($cleanedContent, true);
    }


    private function buildPrompt($rawText)
    {
        return "
    Given the following raw text extracted from a sign-in sheet, structure the data in JSON format with the following fields:
    - development_name
    - date
    - contract_no
    - contractor
    - employees: A list of employees where each entry contains 'name', 'time_in', 'time_out', 'work_classification', and 'ssn_last_4_digits'.
    Ensure that
    - The 'work_classification' will be the following: (79, BL, PCC).
    - Skip everything after the text similar to 'CONTRACTORS CERTIFICATION STATEMENT'.
    Here is the text:
    $rawText
    ";
    }


}
