import re

# Raw text extracted from Textract
raw_text = """
X,PCC
CONTRACTOR DAILY
NEW YORK CITY HOUSING AUTHORITY
SIGN-IN SHEET
RELEASE OR T.O NO.
DATE 9/10/24
CONTRACT NO
DEVELOPMENT
East River Houses
BW1835765
SUBCONTRACTOR & ADDRESS
CONTRACTOR & ADDRESS P&K Contracting inc
TIME-IN
NAME
MoltBanMED (print) K Hossalds
SIGNATURE-IN Kroom
8 AN
SSN (last 4 digits)
SIGNATURE-OUT Kanon
TIME OUT
WORK CLASSIFICATION
PCC
5316
4.30
NAME (print)
TIME-IN
Anil Gorung
SIGNATURE-IN Aricing
8:00
WORK CLASSIFICATION
SSN (last 4 digits)
SIGNATURE-OUT Ailking
TIME-OUT
PCC
6639
10:00
NAME
(print) Laxhin guring
SIGNATURE-IN Talm
TIME-IN
8.5
WORK CLASSIFICATION
SSN (last 4 digits)
SIGNATURE-OUT later
TIME-OUT
PCL
8177
10.00
NAME (print)
SIGNATURE-IN
TIME-IN
RiNgCHEN
CICO
WORK CLASSIFICATION
SSN (last 4 digits)
SIGNATURE-OUT
TIME-OUT
OCC
8563
RINCHEN
10:10
NAME (print) Pemawangchu
TIME-IN
SIGNATURE-IN pema
8.00
WORK CLASSIFICATION
SSN (last 4 digits)
SIGNATURE-OUT
TIME-OUT
PCC
1136
Power
toma
10.Am
NAME (print)
SIGNATURE-IN
with
TIME-IN
Pemba Tashi
8.00
WORK CLASSIFICATION
SSN (last 4 digits)
SIGNATURE-OUT
Pcc
3124
ALL
TIME-OUT
4.30
NAME (print)
SIGNATURE-IN
TIME-IN
Malcolm Whitten
MB
8100
WORK CLASSIFICATION
SSN (last 4 digits)
SIGNATURE-OUT
TIME-OUT
eu
1673
MB
4.30
NAME (print)
SIGNATURE-IN
TIME-IN
WORK CLASSIFICATION
SSN (last 4 digits)
SIGNATURE OUT
TIME-OUT
NAME (print)
SIGNATURE-IN
TIME-IN
WORK CLASSIFICATION
SSN (last 4 digits)
SIGNATURE-OUT
TIME-OUT
CONTRACTOR'S CERTIFICATION STATEMENT
NOTICE: The Willful Falsification of any of the above statements may subject the signer, contractor and/or subcontractor to civil or
criminal prosecution, See Section 1001 of Title 18 and Section 231 of Title 31 of the United States Code.
Bilal Hassan
I,
Superintendent
(Print name)
(Title)
(Signature of General Contractor Representative)
Drs
DISTRIBUTION: Original to Construction Project Manager Copy to Development Superintendent Copy to Contractor
NYCHA 076.026 (Rev. 2/12/19)v3
"""

# Initialize the structure
structured_data = {
    "development_name": "",
    "date": "",
    "contract_no": "",
    "contractor": "",
    "employees": []
}

# Regex patterns to extract fields
development_name_pattern = r"DEVELOPMENT\s*(.*)"
date_pattern = r"DATE\s*(\d{1,2}/\d{1,2}/\d{2,4})"
contract_no_pattern = r"CONTRACT NO\s*(.*)"
contractor_pattern = r"CONTRACTOR & ADDRESS\s*(.*)"
employee_pattern = r"NAME.*?\n(.+?)\s*SIGNATURE-IN.*?\n(.+?)\s*\nSSN \(last 4 digits\)\s*(\d{4}).*?\nWORK CLASSIFICATION\s*(.*?)\s*(\d{4}).*?\n(.+?)\s*"

# Extracting fields
structured_data["development_name"] = re.search(development_name_pattern, raw_text).group(1).strip()
structured_data["date"] = re.search(date_pattern, raw_text).group(1).strip()
structured_data["contract_no"] = re.search(contract_no_pattern, raw_text).group(1).strip()
structured_data["contractor"] = re.search(contractor_pattern, raw_text).group(1).strip()

# Extract employee data
employee_matches = re.findall(employee_pattern, raw_text, re.DOTALL)
for match in employee_matches:
    employee = {
        "name": match[0].strip(),
        "time_in": match[1].strip(),
        "time_out": match[5].strip(),
        "work_classification": match[3].strip(),
        "ssn_last_4_digits": match[4].strip()
    }
    structured_data["employees"].append(employee)

# Print the structured JSON data
import json
print(json.dumps(structured_data, indent=2))
